data module
===========

This section contains the Python API reference for the ``uncertainty_toolbox.data``
module, which contains code for importing and generating data.

uncertainty_toolbox.data Module
###############################

.. automodule:: uncertainty_toolbox.data
    :members:
